# Contributing Guidelines

:tada: **First off, thank you for considering contributing to our project!** :tada:

This is a community-driven project, so it's people like you that make it useful and
successful. These are some of the many ways to contribute:

* :bug: Submitting bug reports and feature requests
* :memo: Writing tutorials or examples
* :mag: Fixing typos and improving the documentation
* :bulb: Writing code for everyone to use
* :people_holding_hands: Community engagement and outreach

If you get stuck at any point you can create an
[issue](https://github.com/montan-code/nfdinspector/issues) on GitHub.


## Ground Rules

The goal is to maintain a diverse community that's pleasant for everyone.
**Please be considerate and respectful of others**. Everyone must abide by our
[Code of Conduct](https://github.com/montan-code/nfdinspector/blob/master/code_of_conduct.md)
and we encourage all to read it carefully.